#
# spec file for package RemoteBox
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# We need to filter some dependencies that the RPM auto-dependency
# gatherer picks up as they reside within this RPM.
%global __requires_exclude ^perl\\(.*\\.pl\\)|^perl\\(vboxService\\)
# We don't want to be a provider of vboxService as it's private
# to remotebox so filter it
%global __provides_exclude ^perl\\(vboxService\\)
Name:           RemoteBox
Version:        3.3
Release:        1.2
Summary:        A VirtualBox client with remote management
License:        GPL-2.0-or-later
Group:          System/Emulators/PC
URL:            http://knobgoblin.org.uk
Source0:        http://knobgoblin.org.uk/downloads/%{name}-%{version}.tar.bz2
Source1:        http://knobgoblin.org.uk/docs/remotebox.pdf
Patch0:         RemoteBox-3.3_fix-env-script-interpreter.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
Requires:       freerdp
Requires:       perl-Gtk3
Requires:       perl-SOAP-Lite
Requires:       typelib-1_0-GdkPixdata-2_0
Requires:       xdg-utils
BuildArch:      noarch

%description
VirtualBox is traditionally considered to be a virtualization solution aimed
at the desktop as opposed to other solutions such as KVM, Xen and VMWare ESX
which are considered more server orientated solutions. While it is certainly
possible to install VirtualBox on a server, it offers few remote management
features beyond using the vboxmanage command line. RemoteBox aims to fill
this gap by providing a graphical VirtualBox client which is able to
communicate with and manage a VirtualBox server installation.

%prep
%autosetup -p0
install -m 0644 %{SOURCE1} .
# Set the locations of Remotebox's files
sed -i 's|\$Bin/share/remotebox|%{_datadir}/%{name}|g' remotebox
sed -i 's|\$Bin/docs|%{_docdir}/%{name}|g' remotebox
# We need to update the reference to the .desktop file, as this package provides RemoteBox, instead of remotebox
sed -i 's|remotebox.desktop|RemoteBox.desktop|' packagers-readme/remotebox.appdata.xml

%build
# Create a desktop file
cat >%{name}.desktop <<EOF
[Desktop Entry]
Type=Application
Name=RemoteBox
GenericName=RemoteBox
Comment=Remote VirtualBox client
Exec=%{name} %c
Icon=%{name}
Terminal=false
StartupNotify=false
Categories=Emulator;System;
X-SuSE-translate=false
EOF

%install
mkdir -p -m0755 %{buildroot}%{_datadir}/{%{name},pixmaps,applications,appdata}
mkdir -m0755 %{buildroot}%{_bindir}
install -p -m0755 remotebox %{buildroot}%{_bindir}/%{name}
cp -a share/remotebox/* %{buildroot}%{_datadir}/%{name}

# Install the .desktop file
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{name}.desktop

# Install an icon for the desktop file
install -p -m0644 share/remotebox/icons/remotebox.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
# link the icon back to the install directory. In preparation for app containerisation, as well
# as AppStream metadata generation, we need a real file in /usr/share/icons
# fdupes later on is likely to put the symlink there though
ln -sf %{_datadir}/pixmaps/%{name}.png %{buildroot}%{_datadir}/%{name}/icons/remotebox.png

# Install upstream provided appdata.xml
install -p -m0644 packagers-readme/remotebox.appdata.xml %{buildroot}%{_datadir}/appdata/RemoteBox.appdata.xml

%fdupes -s %{buildroot}

%check
desktop-file-validate %{buildroot}/%{_datadir}/applications/%{name}.desktop

%files
%license docs/COPYING
%doc docs/changelog.txt  remotebox.pdf
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/%{name}
%{_bindir}/%{name}

%changelog
* Mon Sep 30 2024 Christian Galeffi <chri@gallochri.com>
-Update to 3.3
  * RemoteBox now requires VirtualBox 7.1.x.
  * Updated OS icons.
  * Added support for VirtioSound Audio Controller.
  * Implemented refresh function for guest logs, the button was
  available but actually did nothing.
  * Changed the default freerdp client preset. VirtualBox now issues
  self-signed certs on RDP connections, the new default ignores
  certificate verification as RemoteBox cannot prompt you.
  * Added Remmina as a VNC/RDP client preset.
  * Significant work on removing dependence on Glade and GTKBuilder.
  * VirtualBox now uses self-signed certs on RDP connections.
  You will need to reset your RDP settings in the RemoteBox
  Preferences -> Guest Display Tab, by selecting a preset.
  * RemoteBox 3.3 requires the Perl module Time-HiRes to be installed
  if not already.
  * RemoteBox 3.3 should run on ARM based Macs fine, but using ARM
  based Macs as the server is NOT supported.
-RemoteBox-3.0_fix-env-script-interpreter.patch update to
  RemoteBox-3.3_fix-env-script-interpreter.patch
* Wed May 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN syntax.
* Sat Jan 21 2023 gallochri <chri@gallochri.com>
- Update to 3.2
  - RemoteBox now requires VirtualBox 7.0.x
  - Started the process of moving away from Glade and implementing
    GUI code natively. This is significant effort and involves a
    large amount of code churn which will span many releases.
  - Added option to attach an ISO when creating a new guest
  - Added support for setting the TPM (Trusted Platform Module) types
    TPM v1.2
    TPM v2.0
  - Added support for setting Secure Boot (where supported)
  - Added support for the following network cards:
    Novell NE2000
    Novell NE1000
    WD/SMC EtherCard Plus 16
    WD/SMC EtherCard Plus
    3Com EtherLink II
    3Com EtherLink
  - Added support for the Windows Audio System (WAS)
  - Added support for USB Multi-Touch screen and pad
  - Added ability to edit an IPv4 Port Forwarding rule
  - Added ability to edit an IPv6 Port Forwarding rule
  - Added 'Devices' menu with items orignally in the 'Machine' menu
  - Added 'Actions' menu with items orignally in the 'Machine' menu
  - Added 'New Floppy Disk Image' to the 'Change Floppy' menu
  - Added 'Add Floppy Disk Image' to the 'Change Floppy' menu
  - Added 'Add Floppy Disk Image' to the menus when editing storage
    menu when attaching storage in
  - Added 'Add Optical Disc Image' to the 'Change Optical Disc' menu
  - Added 'Add Optical Disc Image' to the menus when editing storage
  - The 'Devices' menu now pops up instead of the 'Machine' menu on
    an RMB event on the guest list
  - The 'Change Floppy' and 'Change Optical Disc' menus are now
    usable with guests that are powered off
  - Updated many operating system icons
  - Added several new dialog motifs
  - Various minor GUI tweaks
* Wed Mar 30 2022 ecsos <ecsos@opensuse.org>
- Update to 3.1
  - Changed the RemoteBox logo
  - Various minor GUI tweaks
  - Added button to save the message log to a text file. Might be
    useful for debugging purposes.
  - Fixed: Regression introduced in 3.0 caused Connection Profiles
    dialog to essentially stop working correctly, potentially
    losing existing profiles in the process.
  - Fixed: Regression introduced in 3.0 meant that NAT rules were
    not shown for IPv4 and IPv6 networks
  - Fixed column sorting in the VMM (Virtual Media Manager)
  - Fixed various list selection bugs. The get_selected() method
    under GTK3 returns both the model and the iterator, not just
    the iterator as with GTK2
  - RemoteBox is no longer bundled with a PDF manual. Documentation
    is now exclusively maintained on the RemoteBox web site.
* Fri Jan  7 2022 gallochri <chri@gallochri.com>
- Update RemoteBox.spec file
  - Renamed patch RemoteBox-2.7_fix-env-script-interpreter.patch
    to RemoteBox-3.0_fix-env-script-interpreter.patch
  - Added Requires typelib-1_0-GdkPixdata-2_0
* Thu Dec 23 2021 ecsos <ecsos@opensuse.org>
- Update to 3.0
  - RemoteBox has been ported to Gtk3.
    Review the requirements before updating to ensure your
    operating system is compatible.
- Changes from 2.8
  The changes don't really justify a release however this is likely
  to be the last release of RemoteBox based on Gtk2 as RemoteBox is
  being ported to Gtk3.
  - Removed hearbeat option as it's no longer required
  - Server memory bar updates changed to 58 seconds
  - Added option to bind the RDP/VNC server for a guest to a
    specific IP or hostname.
  - Fixed copy and clone of disks. Regression caused by passsing
    incorrect datatype to the API
  - Added OS icon for Windows 11
* Wed Feb 19 2020 chri@gallochri.com
- RemoteBox-2.6_fix-env-script-interpreter.patch remamed for to
  RemoteBox-2.7_fix-env-script-interpreter.patch.
* Wed Dec 18 2019 ecsos@opensuse.org
- Update to 2.7 version
  - RemoteBox now requires VirtualBox 6.1.x
  - VirtualBox now requires hardware virtualization and no longer
    supports software virtualization. Removed associated options
    from RemoteBox.
  - Removed option of setting the video side-channel quality for an
    RDP connection. This option is largely unsupported by RDP
    clients and not particularly useful.
  - Added support for the Virtio-SCSI controller
  - Added support for the AMD PCNet-ISA/NE2100 network card
  - Added support for nested hardware virtualization (VT-x/AMD-V)
    for supported processors
  - Added toolbar buttons in the VMM to create new hard disk
    images, new floppy disk images (from 360K to 2.88MB) and move
    media to new locations
  - Newly created floppy disk images can be optionally
    pre-formatted with FAT12
  - Added a menu option when attached storage for creating a new
    floppy disk image and automatically attaching it
  - Added option to specify MAC address policy when importing an
    appliance
  - Added options to specify MAC address policy and include ISO
    files when exporting an appliance
  - Added options to Keep disk UUIDs, specify MAC policy and keep
    disk names when cloning a guest
  - Added OS icon for Windows 2019 64bit
  - Rewrote the copy and disk conversion code, should be cleaner
    and faster
  - Creating a new guest, now uses the ApplyDefaults API call which
    was broken in previous versions of VirtualBox. This allows
    a lot of code cleanups and faster guest creation
  - Fixed incorrect URL on About window
  - Various code cleanups
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sat Mar 16 2019 chri@gallochri.com
- Update to 2.6 version
- Removed old version of env-script-interpreter.patch
- Added RemoteBox-2.6_fix-env-script-interpreter.patch
- RemoteBox now requires VirtualBox 6.0.x
- Added additional screen modes for video capture and video hinting
- Added option to select between Video and Audio, Video Only or
  Audio Only when screen capturing
- Added support for VirtualBox VGA card with VMware SVGA II
  extensions
- Added support for having no graphics card in the guest. Note
  however, you cannot connect to the guest with RDP/VNC without a
  virtual graphics card.
- Added support for setting the emulated serial UART type
- The Audio Input and Audio Output options can now also be set
  while the guest is running
- Added support to the VMM (Virtual Media Manager) for compaction
  of hard disk images to reduce their physical size
- Added support to the VMM (Virtual Media Manager) for resizing
  hard disk images
- Added ability to save a guest log to a local text file
- Added refresh button to reload the guest logs in the log viewer
- Added cancel button to the VirtualBox Preferences dialog
- Removed Host-Only-Network and NAT Network configuration from
  the VirtualBox preferences dialog and created the Host Network
  Manager dialog accessible from the file menu
- Significantly updated the RemoteBox icon set and added
  additional decals
- To work around a VirtualBox bug, when changing a shared folder
  the guest settings are now explicitly saved. This includes
  adding, editing and deleting
- Optimised a lot of the settings retrieval code which should
  improve latency especially for those on slower systems and
  networks.
- Fixed the Edit Shared Folder dialog not correctly showing a
  share's Permanent Status, when editing the shared folder.
- Various code cleanups
* Sun May 20 2018 ecsos@opensuse.org
- Update to 2.5 version
  - RemoteBox now only pops up a VirtualBox Extensions warning
    dialog on login, for server operating systems that have them
    available but the extension pack
    is not installed. Currently this is Linux, Solaris, Windows and
    MacOS X. Others such as FreeBSD will just get a warning in the
    message log as there are no VirtualBox extensions.
  - Added support for setting the Audio driver of a guest when
    using a FreeBSD server
  - Improved the code which automatically adds the guest addition
    ISO to the VMM on login which should prevent an error if the
    server does not provide a guest additions ISO
  - Added support for VNC. If your server has the VNC extension
    pack installed, you can use VNC to connect to the guest
    displays instead of RDP. You must install a VNC client on your
    RemoteBox machine and configured it as appropriate in your
    preferences. TigerVNC is the default client
  - The guest display icon now shows whether the server expects
    a VNC or RDP connection when opening the display of guests.
  - Added option to change the floppy drive type to 360k, 720k,
    1.44MB, 2.88MB, 15.6MB and 63.5MB.
  - Added a button to assist with the automatic generation of
    serial port paths
  - Fixed a bug causing the port path setting to be reset with the
    defaults
  - Fixed audio support for Solaris servers. The SolAudio driver is
    non functional in VirtualBox and has been replaced with OSS.
* Mon Nov  6 2017 chri@gallochri.com
-Update to 2.4 version
-RemoteBox now requires VirtualBox 5.2.x
-Updated guest icons
-Added option to enable/disable audio output from a guest
-Added option to enable/disable audio input to a guest
-Added option to record audio from the guest when capturing a video
-Added support for exporting appliances to Oracle Public Cloud
  Format 1.0
-Added ability to select a connection profile to use for
  automatically logging in when starting up RemoteBox.
-Added option 'Release Keys' to clear any held keys in the case
  where a host and guest's keyboard status may become out of sync.
-New guests now automatically have their audio output enabled
-Fixed: You now can't set video RAM to zero, even though VirtualBox
  reports this as a valid minimum, the guest won't start.
- env-script-interpreter.patch fix pearl interpreter script
* Sat May 20 2017 chri@gallochri.com
-Updtae to 2.3 version
* Thu Aug 18 2016 chri@gallochri.com
-Update to 2.2 version
* Fri Jul 29 2016 chri@gallochri.com
-Update to 2.1 version
* Sun Jul 12 2015 chri@gallochri.com
-Updated to 2.0 version
* Thu Apr  2 2015 dimstar@opensuse.org
- Manually symlink the duplicate icon between /usr/share/icons and
  /usr/share/RemoteBox. This allows us, contrary to the use of
  fdupes, to define that we want the real file in /usr/share/icons,
  which is a requirement for Application containerisation (the icon
  needs to be extractable from a defined location for host system
  integration).
* Sun Mar 29 2015 dimstar@opensuse.org
- Install upstream provided appdata.xml file.
* Thu Oct 30 2014 chri@gallochri.com
-Fixed SLE_11_SP3 build
* Sun Oct 26 2014 chri@gallochri.com
-Updated to 1.9 version
* Sat Aug 16 2014 wr@rosenauer.org
- added RPM group tag matching other Virtualization packages
* Thu Jun 19 2014 chri@gallochri.com
- Changes name fixed
* Thu Jun 19 2014 chri@gallochri.com
- Package name fixed
* Mon Jun  9 2014 chri@gallochri.com
- Fixed doc dir path
* Mon Jun  9 2014 chri@gallochri.com
- Updated to version 1.8.1
* Fri Jun  6 2014 chri@gallochri.com
- Added perl-SOAP-Lite as required
* Thu Jun  5 2014 chri@gallochri.com
- ops, patch missed ;-)
* Thu Jun  5 2014 chri@gallochri.com
- Soap Version patch added
* Wed Jun  4 2014 chri@gallochri.com
- First version
* Wed Jun  4 2014 chri@gallochri.com
- Init
